Type Definition move_ir_types::ast::StructTypeParameter
source · [−]Expand description
A struct type parameter with its constraints and whether it’s declared as phantom.
A struct type parameter with its constraints and whether it’s declared as phantom.